==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookListDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-结算甲方供应材料扣款清单
 * 
 * @author generator
 * 
 */
public class SettlementBookListDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String humanName; // 人材机名称
    private java.lang.String units; // 单位
    private java.lang.Long number; // 数量
    private java.math.BigDecimal extaxUnitprice; // 除税单价
    private java.math.BigDecimal intaxUnitprice; // 含税单价
    private java.math.BigDecimal extaxPrice; // 除税金额
    private java.math.BigDecimal intaxPrice; // 含税金额
    private java.lang.String remarks; // 备注
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 人材机名称
     */
    public java.lang.String getHumanName() {
        return humanName;
    }

    /**
     * 人材机名称
     */
    public void setHumanName(java.lang.String humanName) {
        this.humanName = humanName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 数量
     */
    public java.lang.Long getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.lang.Long number) {
        this.number = number;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExtaxUnitprice(java.math.BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExtaxPrice() {
        return extaxPrice;
    }

    /**
     * 除税金额
     */
    public void setExtaxPrice(java.math.BigDecimal extaxPrice) {
        this.extaxPrice = extaxPrice;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getIntaxPrice() {
        return intaxPrice;
    }

    /**
     * 含税金额
     */
    public void setIntaxPrice(java.math.BigDecimal intaxPrice) {
        this.intaxPrice = intaxPrice;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20221022.042622-79-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookListDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-结算甲方供应材料扣款清单
 * 
 * @author generator
 * 
 */
public class SettlementBookListDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String humanName; // 人材机名称
    private java.lang.String units; // 单位
    private java.lang.Long number; // 数量
    private java.math.BigDecimal extaxUnitprice; // 除税单价
    private java.math.BigDecimal intaxUnitprice; // 含税单价
    private java.math.BigDecimal extaxPrice; // 除税金额
    private java.math.BigDecimal intaxPrice; // 含税金额
    private java.lang.String remarks; // 备注
    private java.lang.String errorMessage; // 错误信息


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 人材机名称
     */
    public java.lang.String getHumanName() {
        return humanName;
    }

    /**
     * 人材机名称
     */
    public void setHumanName(java.lang.String humanName) {
        this.humanName = humanName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 数量
     */
    public java.lang.Long getNumber() {
        return number;
    }

    /**
     * 数量
     */
    public void setNumber(java.lang.Long number) {
        this.number = number;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExtaxUnitprice() {
        return extaxUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExtaxUnitprice(java.math.BigDecimal extaxUnitprice) {
        this.extaxUnitprice = extaxUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIntaxUnitprice() {
        return intaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setIntaxUnitprice(java.math.BigDecimal intaxUnitprice) {
        this.intaxUnitprice = intaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExtaxPrice() {
        return extaxPrice;
    }

    /**
     * 除税金额
     */
    public void setExtaxPrice(java.math.BigDecimal extaxPrice) {
        this.extaxPrice = extaxPrice;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getIntaxPrice() {
        return intaxPrice;
    }

    /**
     * 含税金额
     */
    public void setIntaxPrice(java.math.BigDecimal intaxPrice) {
        this.intaxPrice = intaxPrice;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }
}
